summaryrefslogtreecommitdiffstats
path: root/akregator/src/librss/loader.h
diff options
context:
space:
mode:
Diffstat (limited to 'akregator/src/librss/loader.h')
-rw-r--r--akregator/src/librss/loader.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/akregator/src/librss/loader.h b/akregator/src/librss/loader.h
index d60bad744..e958239f2 100644
--- a/akregator/src/librss/loader.h
+++ b/akregator/src/librss/loader.h
@@ -15,7 +15,7 @@
class KURL;
-#include <qobject.h>
+#include <tqobject.h>
namespace KIO
{
@@ -75,7 +75,7 @@ namespace RSS
* wrong and that the data parameter might contain no or invalid
* data.
*/
- void dataRetrieved(const QByteArray &data, bool success);
+ void dataRetrieved(const TQByteArray &data, bool success);
private:
DataRetriever(const DataRetriever &other);
@@ -120,8 +120,8 @@ namespace RSS
virtual void abort();
static void setUseCache(bool enabled);
- static void setUserAgent(const QString &ua);
- static QString userAgent();
+ static void setUserAgent(const TQString &ua);
+ static TQString userAgent();
signals:
/**
@@ -137,7 +137,7 @@ namespace RSS
void slotTimeout();
private slots:
- void slotData(KIO::Job *job, const QByteArray &data);
+ void slotData(KIO::Job *job, const TQByteArray &data);
void slotResult(KIO::Job *job);
void slotPermanentRedirection(KIO::Job *job, const KURL &fromUrl,
const KURL &toUrl);
@@ -208,8 +208,8 @@ namespace RSS
*
* \code
* Loader *loader = Loader::create();
- * connect(loader, SIGNAL(loadingComplete(Loader *, Document, Status)),
- * this, SLOT(slotLoadingComplete(Loader *, Document, Status)));
+ * connect(loader, TQT_SIGNAL(loadingComplete(Loader *, Document, Status)),
+ * this, TQT_SLOT(slotLoadingComplete(Loader *, Document, Status)));
* loader->loadFrom("http://www.blah.org/foobar.rdf", new FileRetriever);
* \endcode
*
@@ -241,7 +241,7 @@ namespace RSS
* if (status != RSS::Success)
* return;
*
- * QString title = doc.title();
+ * TQString title = doc.title();
* // do whatever you want with the information.
* }
* \endcode
@@ -270,10 +270,10 @@ namespace RSS
* Convenience method. Does the same as the above method except that
* it also does the job of connecting the loadingComplete() signal
* to the given slot for you.
* @param object A QObject which features the specified slot
* @param slot Which slot to connect to.
*/
- static Loader *create(QObject *object, const char *slot);
+ static Loader *create(TQObject *object, const char *slot);
/**
* Loads the RSS file referenced by the given URL using the
@@ -323,14 +323,14 @@ namespace RSS
void loadingComplete(Loader *loader, Document doc, Status status);
private slots:
- void slotRetrieverDone(const QByteArray &data, bool success);
+ void slotRetrieverDone(const TQByteArray &data, bool success);
private:
Loader();
Loader(const Loader &other);
Loader &operator=(const Loader &other);
~Loader();
- void discoverFeeds(const QByteArray &data);
+ void discoverFeeds(const TQByteArray &data);
struct Private;
Private *d;
@@ -270,10 +270,10 @@ namespace RSS
* it also does the job of connecting the loadingComplete() signal
* to the given slot for you.
- * @param object A QObject which features the specified slot
+ * @param object A TQObject which features the specified slot
* @param slot Which slot to connect to.
*/